==> haskell-containers-unicode-symbols-0.3.1.3-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-containers-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 containers-unicode-symbols
version:              0.3.1.3
visibility:           public
id:                   containers-unicode-symbols-0.3.1.3-2Nlibk3yBrKBwgsKxSV8rb
key:                  containers-unicode-symbols-0.3.1.3-2Nlibk3yBrKBwgsKxSV8rb
license:              BSD-3-Clause
copyright:            2009—2021 Roel van Dijk <roel@lambdeacube.nl>
maintainer:           Roel van Dijk <roel@lambdeacube.nl>
author:               Roel van Dijk <roel@lambdeacube.nl>
stability:            provisional
homepage:             http://haskell.org/haskellwiki/Unicode-symbols
synopsis:             Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions and
    operators in the containers package.

    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.

abi:                  e11509de468add5e2fea0e27c72bbc3c
exposed:              True
exposed-modules:
    Data.IntMap.Lazy.Unicode Data.IntMap.Strict.Unicode
    Data.IntMap.Unicode Data.IntSet.Unicode Data.Map.Lazy.Unicode
    Data.Map.Strict.Unicode Data.Map.Unicode Data.Sequence.Unicode
    Data.Set.Unicode

import-dirs:
    /usr/lib/ghc-9.0.1/site-local/containers-unicode-symbols-0.3.1.3

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/containers-unicode-symbols-0.3.1.3

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/containers-unicode-symbols-0.3.1.3

hs-libraries:         HScontainers-unicode-symbols-0.3.1.3-2Nlibk3yBrKBwgsKxSV8rb
depends:
    base-4.15.0.0 base-unicode-symbols-0.2.4.2-6HQW130bkmx2yCjqaWNHi2
    containers-0.6.4.1

haddock-interfaces:
    /usr/share/doc/haskell-containers-unicode-symbols/html/containers-unicode-symbols.haddock

haddock-html:         /usr/share/doc/haskell-containers-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-containers-unicode-symbols-0.3.1.3-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-containers-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 containers-unicode-symbols
version:              0.3.1.3
visibility:           public
id:                   containers-unicode-symbols-0.3.1.3-JsDvEZ7LhPw7z4hTGmeecL
key:                  containers-unicode-symbols-0.3.1.3-JsDvEZ7LhPw7z4hTGmeecL
license:              BSD-3-Clause
copyright:            2009—2021 Roel van Dijk <roel@lambdeacube.nl>
maintainer:           Roel van Dijk <roel@lambdeacube.nl>
author:               Roel van Dijk <roel@lambdeacube.nl>
stability:            provisional
homepage:             http://haskell.org/haskellwiki/Unicode-symbols
synopsis:             Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions and
    operators in the containers package.

    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.

abi:                  7b0310bb601e2c413e20760990708003
exposed:              True
exposed-modules:
    Data.IntMap.Lazy.Unicode Data.IntMap.Strict.Unicode
    Data.IntMap.Unicode Data.IntSet.Unicode Data.Map.Lazy.Unicode
    Data.Map.Strict.Unicode Data.Map.Unicode Data.Sequence.Unicode
    Data.Set.Unicode

import-dirs:
    /usr/lib/ghc-9.0.2/site-local/containers-unicode-symbols-0.3.1.3

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/containers-unicode-symbols-0.3.1.3

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/containers-unicode-symbols-0.3.1.3

hs-libraries:         HScontainers-unicode-symbols-0.3.1.3-JsDvEZ7LhPw7z4hTGmeecL
depends:
    base-4.15.1.0 base-unicode-symbols-0.2.4.2-3I3pSMQwGEB5P9J2UkMzWs
    containers-0.6.4.1

haddock-interfaces:
    /usr/share/doc/haskell-containers-unicode-symbols/html/containers-unicode-symbols.haddock

haddock-html:         /usr/share/doc/haskell-containers-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
